Add-Type -AssemblyName System.Windows.Forms
Add-Type -AssemblyName System.Drawing

# Function to download Sysmon configuration
function Download-SysmonConfig {
    $url = "https://raw.githubusercontent.com/olafhartong/sysmon-modular/refs/heads/master/sysmonconfig.xml"
    $outputPath = "$env:TEMP\sysmonconfig.xml"
    Invoke-WebRequest -Uri $url -OutFile $outputPath
    return $outputPath
}

# Function to check Sysmon installation status
function Check-SysmonStatus {
    $sysmonService = Get-Service -Name "Sysmon64" -ErrorAction SilentlyContinue
    if ($sysmonService) {
        $status = $sysmonService.Status
        $processExists = (Get-Process -Name "Sysmon64" -ErrorAction SilentlyContinue) -ne $null
        return "Installed (Service: $status, Process Running: $processExists)"
    }
    return "Not Installed"
}

# Create main form
$form = New-Object System.Windows.Forms.Form
$form.Text = "Sysmon Installation Manager"
$form.Size = New-Object System.Drawing.Size(400, 300)
$form.StartPosition = "CenterScreen"

# Status Label
$statusLabel = New-Object System.Windows.Forms.Label
$statusLabel.Location = New-Object System.Drawing.Point(10, 20)
$statusLabel.Size = New-Object System.Drawing.Size(380, 30)
$statusLabel.Text = "Current Sysmon Status: $(Check-SysmonStatus)"
$form.Controls.Add($statusLabel)

# Install Button
$installButton = New-Object System.Windows.Forms.Button
$installButton.Location = New-Object System.Drawing.Point(10, 60)
$installButton.Size = New-Object System.Drawing.Size(150, 30)
$installButton.Text = "Install Sysmon"
$installButton.Add_Click({
    try {
        # Download Sysmon config
        $configPath = Download-SysmonConfig

        # Download Sysmon executable
        $sysmonZip = "$env:TEMP\Sysmon.zip"
        Invoke-WebRequest -Uri "https://download.sysinternals.com/files/Sysmon.zip" -OutFile $sysmonZip
        Expand-Archive -Path $sysmonZip -DestinationPath $env:TEMP -Force

        # Install Sysmon
        Start-Process -FilePath "$env:TEMP\Sysmon64.exe" -ArgumentList "-accepteula", "-i", $configPath -Verb RunAs -Wait

        # Update status
        $statusLabel.Text = "Installation Complete. Status: $(Check-SysmonStatus)"
    }
    catch {
        [System.Windows.Forms.MessageBox]::Show("Installation Failed: $_", "Error", [System.Windows.Forms.MessageBoxButtons]::OK, [System.Windows.Forms.MessageBoxIcon]::Error)
    }
})
$form.Controls.Add($installButton)

# Uninstall Button
$uninstallButton = New-Object System.Windows.Forms.Button
$uninstallButton.Location = New-Object System.Drawing.Point(170, 60)
$uninstallButton.Size = New-Object System.Drawing.Size(150, 30)
$uninstallButton.Text = "Uninstall Sysmon"
$uninstallButton.Add_Click({
    try {
        # Uninstall Sysmon
        Start-Process -FilePath "$env:TEMP\Sysmon64.exe" -ArgumentList "-u" -Verb RunAs -Wait

        # Update status
        $statusLabel.Text = "Uninstallation Complete. Status: $(Check-SysmonStatus)"
    }
    catch {
        [System.Windows.Forms.MessageBox]::Show("Uninstallation Failed: $_", "Error", [System.Windows.Forms.MessageBoxButtons]::OK, [System.Windows.Forms.MessageBoxIcon]::Error)
    }
})
$form.Controls.Add($uninstallButton)


# Show form
$form.Add_Shown({$form.Activate()})
$form.ShowDialog()